@@ -5,18 +5,35 @@ class TablateApiItem(TablateApiBase):
 
     @property
     def name(self):
-        for frame_key in list(self._frame_list.items())[0]:
-            return frame_key
+        """
+
+        Returns: The name of the frame.
+
+        """
+        return list(self._frame_list.items())[0]
+
+    @name.setter
+    def name(self, name: str):
+        self.rename(name)
 
     def rename(self, new_name: str):
+        """
+        Renames the frame.
+        Args:
+            new_name: The new name set on the frame.
+        """
         if new_name is not None:
             frame_key, frame_item = list(self._frame_list.items())[0]
             frame_item.name = new_name
             self._frame_list[new_name] = frame_item
             del self._frame_list[frame_key]
 
-
     def to_dict(self):
+        """
+
+        Returns: A Pandas compatible dict.
+
+        """
         frame_key, frame_item = list(self._frame_list.items())[0]
         if frame_item.type == "text":
             return {
