@@ -8,12 +8,12 @@ def render_console_foot(frame_list: FrameStoreList, global_options: Globals) ->
 
     return_string = ""
 
-    outer_padding = global_options.console.outer_styles.outer_padding
-    frame_border = global_options.console.outer_styles.outer_border
+    container_padding = global_options.console.outer_styles.container_padding
+    frame_border = global_options.console.outer_styles.container_border
 
     bottom_border_inner = row_line_divider(column_list_top=frame_list[-1].column_list,
                                            column_list_bottom=[],
                                            divider=frame_border)
-    return_string += f"{' ' * outer_padding}{bottom_left[frame_border]}{bottom_border_inner}{bottom_right[frame_border]}\n"
+    return_string += f"{' ' * container_padding}{bottom_left[frame_border]}{bottom_border_inner}{bottom_right[frame_border]}\n"
 
     return return_string
