@@ -8,14 +8,14 @@ def render_console_head(frame_list: FrameStoreList, global_options: Globals) ->
 
     return_string = ""
 
-    frame_border = global_options.console.outer_styles.outer_border
-    outer_padding = global_options.console.outer_styles.outer_padding
+    frame_border = global_options.console.outer_styles.container_border
+    container_padding = global_options.console.outer_styles.container_padding
 
     top_border_inner = row_line_divider(column_list_top=[],
                                         column_list_bottom=frame_list[0].column_list,
                                         divider=frame_border)
 
 
-    return_string += f"{' ' * outer_padding}{top_left[frame_border]}{top_border_inner}{top_right[frame_border]}\n"
+    return_string += f"{' ' * container_padding}{top_left[frame_border]}{top_border_inner}{top_right[frame_border]}\n"
 
     return return_string
\ No newline at end of file
