@@ -4,7 +4,7 @@ from typing import List, Optional
 from tablate.classes.options.html.style.CssStyler import CssStyler
 from tablate.type.primitives import CssStyleBlock, PxInteger
 from tablate.type.type_style import FrameStyles, ColumnStyles, TextStyles, HtmlFrameStyles, \
-    HtmlColumnStyles, HtmlTextStyles, OuterStyles, HtmlOuterStyles
+    HtmlColumnStyles, HtmlTextStyles, OuterStyles, HtmlContainerStyles
 
 
 @dataclass
@@ -17,7 +17,7 @@ class ConsoleGlobals:
 
 @dataclass
 class HtmlGlobals:
-    html_outer_styles: HtmlOuterStyles = field(default_factory=HtmlOuterStyles)
+    html_container_styles: HtmlContainerStyles = field(default_factory=HtmlContainerStyles)
     html_frame_styles: HtmlFrameStyles = field(default_factory=HtmlFrameStyles)
     html_column_styles: HtmlColumnStyles = field(default_factory=HtmlColumnStyles)
     html_text_styles: HtmlTextStyles = field(default_factory=HtmlTextStyles)
